@@ -1,37 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+import array
+import time
+from collections import namedtuple
 from collections import OrderedDict
 from pprint import pprint
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
-
-import array
-from collections import namedtuple
-import time
-
 from pyxcp import checksum
-from pyxcp import types
 from pyxcp import transport
+from pyxcp import types
 from pyxcp.dllif import getKey
 from pyxcp.master import Master
 from pyxcp.utils import hexDump
@@ -237,7 +213,7 @@ def bench(xm):
     for pn in range(8, 257, 8):
         # for pn in range(8, 257, 32):
         result[pn] = []
-        for i in range(10):
+        for _ in range(10):
             gid = xm.getID(0x4)
             start = time.perf_counter()
             xm.fetch(gid.length, pn)
