@@ -1,41 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2022 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
-
 import abc
-from collections import deque
+import pyxcp.types as types
 import threading
+from collections import deque
 from datetime import datetime
-from time import time, sleep, get_clock_info
+from pyxcp.config import Configuration
+from time import get_clock_info
+from time import sleep
+from time import time
 
 from ..logger import Logger
-from ..utils import flatten, hexDump, time_perfcounter_correlation
-
-import pyxcp.types as types
-from pyxcp.config import Configuration
-
 from ..timing import Timing
+from ..utils import flatten
+from ..utils import hexDump
+from ..utils import time_perfcounter_correlation
 
 
 class Empty(Exception):
