@@ -1,36 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2021 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
-
-from collections import deque
 import selectors
 import socket
 import struct
-from time import perf_counter, time, sleep
 import threading
-
+from collections import deque
 from pyxcp.transport.base import BaseTransport
+from time import perf_counter
+from time import sleep
+from time import time
 
 DEFAULT_XCP_PORT = 5555
 RECV_SIZE = 8196
@@ -122,7 +100,7 @@ class Eth(BaseTransport):
         socket_fileno = self.sock.fileno
         select = self.selector.select
 
-        high_resolution_time = self.perf_counter_origin > 0
+        high_resolution_time = self.perf_counter_origin < 0
         timestamp_origin = self.timestamp_origin
         perf_counter_origin = self.perf_counter_origin
 
@@ -222,7 +200,7 @@ class Eth(BaseTransport):
                             break
 
     def send(self, frame):
-        if self.perf_counter_origin > 0:
+        if self.perf_counter_origin < 0:
             self.pre_send_timestamp = time()
             self.sock.send(frame)
             self.post_send_timestamp = time()
